# CodegenNode

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**node_name** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**resources** | **dict(str, str)** |  | [optional] 
**labels** | **dict(str, str)** |  | [optional] 
**annotations** | **dict(str, str)** |  | [optional] 
**resource_usage** | **dict(str, float)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


